@@ -77,58 +77,56 @@ _gedit_cmd_help_contents (GeditWindow *window)
 void
 _gedit_cmd_help_about (GeditWindow *window)
 {
-	static const gchar * const authors[] = {
-		"Alex Roberts",
-		"Chema Celorio",
-		"Evan Lawrence",
-		"Federico Mena Quintero <federico@novell.com>",
-		"Garrett Regier <garrettregier@gmail.com>",
-		"Ignacio Casal Quinteiro <icq@gnome.org>",
-		"James Willcox <jwillcox@gnome.org>",
-		"Jesse van den Kieboom <jessevdk@gnome.org>",
-		"Paolo Borelli <pborelli@gnome.org>",
-		"Paolo Maggi <paolo@gnome.org>",
-		"Sébastien Lafargue <slafargue@gnome.org>",
-		"Sébastien Wilmet <swilmet@gnome.org>",
-		"Steve Frécinaux <steve@istique.net>",
+	const gchar * const authors[] = {
+		/* Main authors: the top 5 (to not have a too long list), by
+		 * relative contribution (number of commits at the time of
+		 * writing).
+		 */
+		_("Main authors:"),
+		"   Paolo Borelli",
+		"   Sébastien Wilmet",
+		"   Ignacio Casal Quinteiro",
+		"   Jesse van den Kieboom",
+		"   Paolo Maggi",
+		"",
+		_("Many thanks also to:"),
+		"   Alex Roberts",
+		"   Chema Celorio",
+		"   Evan Lawrence",
+		"   Federico Mena Quintero",
+		"   Garrett Regier",
+		"   James Willcox",
+		"   Sébastien Lafargue",
+		"   Steve Frécinaux",
+		"",
+		_("and many other contributors."),
+		"",
 		NULL
 	};
 
 	static const gchar * const documenters[] = {
-		"Jim Campbell <jwcampbell@gmail.com>",
-		"Daniel Neel <dneelyep@gmail.com>",
-		"Sun GNOME Documentation Team <gdocteam@sun.com>",
-		"Eric Baudais <baudais@okstate.edu>",
+		"Daniel Neel",
+		"Eric Baudais",
+		"Jim Campbell",
+		"Sun GNOME Documentation Team",
 		NULL
 	};
 
-	GdkPixbuf *logo;
-	GError *error = NULL;
-
 	gedit_debug (DEBUG_COMMANDS);
 
-	logo = gdk_pixbuf_new_from_resource ("/org/gnome/gedit/pixmaps/gedit-logo.png", &error);
-	if (error != NULL)
-	{
-		g_warning ("Error when loading the gedit logo: %s", error->message);
-		g_clear_error (&error);
-	}
-
 	gtk_show_about_dialog (GTK_WINDOW (window),
 			       "program-name", "gedit",
 			       "authors", authors,
-			       "comments", _("gedit is a small and lightweight text editor for the GNOME desktop"),
-			       "copyright", "Copyright 1998-2021 – the gedit team",
+			       "comments", _("gedit is an easy-to-use and general-purpose text editor"),
+			       "copyright", "Copyright 1998-2022 – the gedit team",
 			       "license-type", GTK_LICENSE_GPL_2_0,
-			       "logo", logo,
+			       "logo-icon-name", "org.gnome.gedit",
 			       "documenters", documenters,
 			       "translator-credits", _("translator-credits"),
 			       "version", VERSION,
 			       "website", "http://www.gedit.org",
 			       "website-label", "www.gedit.org",
 			       NULL);
-
-	g_clear_object (&logo);
 }
 
 /* ex:set ts=8 noet: */
